export interface ConnectInfo {
    type: string;
    connected: boolean;
    msg: string;
}
export interface ServerAssignedData {
    type: string;
    clientId: string;
    serverVersion: string;
}
export interface OnDataArgs {
    type: string;
    subType: string;
    fromClient: string;
    payload: any;
    time: number;
}
export interface ClientPresenceChangedArgs {
    type: string;
    clients: string[];
    clientThatChanged: string;
    time: number;
    present: boolean;
}
export interface Room {
    app: string;
    name: string;
    version: string;
    maxClients?: number;
    togetherTimeoutMs?: number;
    hidden?: boolean;
}
export interface OnRoomsArgs {
    type: string;
    rooms: Room[];
}
export interface Latency {
    min: number;
    max: number;
    averageDataPoints: number[];
    average: number;
}
export default class PieClient {
    env: string;
    onData?: (x: OnDataArgs) => void;
    onError?: ((x: {
        message: string;
    }) => void);
    onServerAssignedData?: ((x: ServerAssignedData) => void);
    onClientPresenceChanged?: ((c: ClientPresenceChangedArgs) => void);
    onRooms?: ((x: OnRoomsArgs) => void);
    onConnectInfo?: ((c: ConnectInfo) => void);
    onLatency?: (l: Latency) => void;
    soloMode: boolean;
    useStats: boolean;
    promiseCBs: {
        joinRoom?: {
            resolve: (x: any) => void;
            reject: (x: any) => void;
        };
    };
    currentRoomInfo?: Room;
    statusElement: HTMLElement | null;
    ws?: WebSocket;
    stats: {
        latency: Latency;
    };
    currentClientId: string;
    reconnectTimeoutId?: ReturnType<typeof setTimeout>;
    reconnectAttempts: number;
    constructor({ env }: {
        env?: string | undefined;
    });
    isConnected(): boolean;
    connect(wsUrl: string, useStats: boolean): Promise<void>;
    connectSolo(): Promise<void>;
    onClose: () => void;
    tryReconnect: () => void;
    disconnect(): Promise<void>;
    handleMessage(message: any, useStats: boolean): void;
    makeRoom(roomInfo: Room): void;
    joinRoom(roomInfo: Room, makeRoomIfNonExistant?: boolean): Promise<void>;
    leaveRoom(): void;
    getRooms(roomInfo: any): void;
    sendData(payload: any, extras?: any): void;
    _updateDebugInfo(message?: {
        clients: object[];
    }): void;
}
